km3pipe.core.AanetGeometry
==========================

.. currentmodule:: km3pipe.core

.. autoclass:: AanetGeometry

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AanetGeometry.__init__
      ~AanetGeometry.add
      ~AanetGeometry.finish
      ~AanetGeometry.get
      ~AanetGeometry.get_detector
      ~AanetGeometry.pre_finish
      ~AanetGeometry.process
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AanetGeometry.name
   
   